@@ -41,19 +41,20 @@ typedef enum
 typedef enum
 {
     LID_KEY   		= (1 << 0),
-    BRIGHTNESS_KEY	= (1 << 1),
-    SLEEP_KEY 		= (1 << 2),
-    HIBERNATE_KEY	= (1 << 3),
-    POWER_KEY 		= (1 << 4)
+    BRIGHTNESS_KEY_UP	= (1 << 1),
+    BRIGHTNESS_KEY_DOWN	= (1 << 2),
+    SLEEP_KEY 		= (1 << 3),
+    HIBERNATE_KEY	= (1 << 4),
+    POWER_KEY 		= (1 << 5)
     
 } XfpmKeys;
 
 typedef enum
 {
-    CPU_UNKNOWN         = (1<<0),
-    CPU_POWERSAVE	= (1<<1),
-    CPU_ONDEMAND	= (1<<2),
-    CPU_PERFORMANCE	= (1<<3)
+    CPU_UNKNOWN         = (1 << 0),
+    CPU_POWERSAVE	= (1 << 1),
+    CPU_ONDEMAND	= (1 << 2),
+    CPU_PERFORMANCE	= (1 << 3)
     
 } XfpmCpuGovernor;
 
